# auntminnnie-update
this package for retirve auntminnie recent news and radiology conference

# how it work?
his package will scarape in [auntminnnie](https://www.auntminnie.com/) to get latest news and radiology conference.
this package use BeautifulSoup4 and requests.
and then produce output of JSON thats ready to use in your web or mobile apps.
